/*

  GPS Module GY-NEO6MV2

  Parts required:
  - Arduino Board
  - GPS Module GY-NEO6MV2

  Libraries required:
  - SoftwareSerial (Included in Arduino IDE)
  - TinyGPS++

  Programming by : René Rasmussen
  Website : www.it-teknolog.dk
  Contact : renerasmussen@it-teknolog.dk
  Date : 7 Apr 2020
  Version : v1.0

*/

#include <TinyGPS++.h>                          // include library TinyGPS++
#include <SoftwareSerial.h>                     // include library SoftwareSerial

static const int RXPin = 4, TXPin = 3;          // set variable RX and TX to digital port 4 and 3
static const uint32_t GPSBaud = 9600;           // set variable GPSBaud to 9600

TinyGPSPlus gps;                                // create object gps from TinyGPSPlus
SoftwareSerial ss(RXPin, TXPin);                // create object ss from SoftwareSerial and set RX and TX ports

void setup() {
  Serial.begin(9600);                           // start Serial Monitor communication
  ss.begin(GPSBaud);                            // start GPS with 9600 baud
}

void loop() {
  while (ss.available() > 0) {
    gps.encode(ss.read());                      // read GPS data
    if (gps.location.isUpdated()) {
      Serial.print("Latitude= ");               // print text to Serial Monitor
      Serial.print(gps.location.lat(), 6);      // print Latitude to Serial Monitor
      Serial.print(" Longitude= ");             // print text to Serial Monitor
      Serial.println(gps.location.lng(), 6);    // print Longitude to Serial Monitor
    }
  }
}
